@@ -8,20 +8,20 @@ use parent qw/SSIS::Package::ConnectionManager/;
 
 =head1 NAME
 
-SSIS::Package::ConnectionManager::ADO.NET - SSIS ADO.NET package connection manager by Ded MedVed
+SSIS::Package::ConnectionManager::ADONET - SSIS ADONET package connection manager by Ded MedVed
 
 =head1 VERSION
 
-Version 0.01
+Version 0.02
 
 =cut
 
-our $VERSION = '0.01';
+our $VERSION = '0.02';
 
 
 1 ;
 
 __DATA__
 
-1; # End of SSIS::Package::ConnectionManager::ADO.NET
+1; # End of SSIS::Package::ConnectionManager::ADONET
 
